parse_data_url

Function parse_data_url 

pub fn parse_data_url(url: &str) -> Option<(String, String)>
Parse a base64 data: URL into (media_type, base64_payload).

Returns None for non-data: URLs, non-base64 data URLs, or a malformed/ empty media type. Provider adapters use this to forward inline image bytes as the provider’s native base64 image part instead of mistakenly sending the whole data: URI as a remote URL reference (which the upstream rejects).